(*
 * coqweb - A WEB-like tool for Coq
 * Copyright (C) 2000 Jean-Christophe FILLIATRE
 * 
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License version 2, as published by the Free Software Foundation.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * See the GNU General Public License version 2 for more details
 * (enclosed in the file GPL).
 *)

(*i $Id: web.mli,v 1.2 2000/10/23 21:25:33 filliatr Exp $ i*)

(*s This module is the heart of the program. The only function is
    [produce_document], which takes a list of files and produces the
    final \LaTeX\ document. *)

(*s Source file structure.  A source file is splitted into paragraphs
   of vernacular and documentation. A new paragraph begins either when
   switching between vernacular and comment or, within vernacular,
   when an empty line occurs.  A paragraph of documentation contains
   arbitrary text. *)

type paragraph =
  | Documentation of string
  | Code of int * string

(* A web section is a numbered part of a source file, which contains a
   sequence of paragraphs. The [sec_beg] field is the character
   position of the beginning of the web section inside the whole file. *)
  
type raw_section = {
  sec_contents : paragraph list;
  sec_beg : int }

(* Finally, the contents of a source file is a sequence of web
   sections. The [content_file] field is the whole file name
   (including dirname and extension) whereas the [content_name] field
   is the corresponding module name *)

type content = { 
  content_file : string;
  content_name : string;
  content_contents : raw_section list } 

(*s A source file is either a vernacular file or any other file, which is
    then considered as a \LaTeX\ file.  *)

type file = 
  | Vernac of content
  | Other  of string

(*s Global options of the engine.
    [extern_defs] indicates if entries used but not defined should appear in 
    the index.
    [add_latex_option] stores \LaTeX\ options to be passed to the 
    \texttt{coqweb.sty} package.
    [index] indicates if the index should be output.
    [web] indicates if we are in WEB style. *)

val extern_defs : bool ref
val add_latex_option : string -> unit
val index : bool ref
val web : bool ref

(*s The following function [produce_document] takes a list of files
    and produces the document. *)

val produce_document : file list -> unit

